Title: Book Review: Charles Murray's <em>Human Diversity: The Biology of Gender, Race, and Class</em>
Date: 2020-01-01
Category: commentary
Tags: Charles Murray, review (book), intelligence, race, sex differences, Emacs, politics, probability, topology, COVID-19
Status: draft

[This is a pretty good book](https://www.twelvebooks.com/titles/charles-murray/human-diversity/9781538744000/) about things we know about some ways in which people are different from each other, including differences in _cognitive repertoires_ (Murray's choice of phrase for shaving nine syllables off "personality, abilities, and social behavior"). In [my last book review](/2020/Jan/book-review-the-origins-of-unfairness/), I mentioned that I had been thinking about broadening the topic scope of this blog, and this book review seems like an okay place to start!

Honestly, I feel like I already knew most of this stuff?—sex differences in particular are kind of _my bag_—but many of the details were new to me, and it's nice to have it all bundled together in a paper book with lots of citations that I can chase down later when I'm skeptical or want more details about a specific thing! The main text is littered with pleonastic constructions like "The first author was Jane Thisand-Such" (when discussing the results of a multi-author paper) or "Details are given in the note<sup>[n]</sup>", which feel clunky to read, but are _so much better_ than the all-too-common alternative of authors _not_ "showing their work".

In the first part of this blog post, I'm going to summarize what I learned from (or was reminded of by) _Human Diversity_, but it would be kind of unhealthy for you to rely too much on tertiary blog-post summaries of secondary semi-grown-up-book literature summaries, so if these topics happen to strike your scientific curiosity, you should probably skip this post and [go buy the source material](https://www.amazon.com/dp/B07Y82KNS1/)—or maybe even a grown-up textbook!

The second part of this blog post is irrelevant.

-----

_Human Diversity_ is divided into three parts corresponding to the topics in the subtitle! (Plus another part if you want some wrapping-up commentary from Murray.) So the first part is about things we know about some ways in which female people and male people are different from each other!

The first (short) chapter is mostly about explaining [Cohen's _d_](https://en.wikiversity.org/wiki/Cohen%27s_d) [effect sizes](https://en.wikipedia.org/wiki/Effect_size), which I think are solving a very important problem! When people say "Men are taller than women" you know they don't mean _all_ men are taller than _all_ women (because you know that they know that that's obviously not true), but that just raises the question of what they _do_ mean. Saying they mean it "generally", "on average", or "statistically" doesn't really solve the problem, because that covers everything between-but-not-including "No difference" to "Yes, literally all women and all men". Cohen's _d_—the difference between two groups' means in terms of their pooled standard deviation—lets us give a _quantitative_ answer to _how much_ men are taller than women: I've seen reports of _d_ ≈ 1.4–1.7 depending on the source, a lot smaller than the sex difference in murder rates (_d_ ≈ 2.5), but much bigger than the difference in verbal skills (_d_ ≈ 0.3, favoring women).

Once you have a quantitative effect size, then you can [visualize the overlapping distributions](https://rpsychologist.com/d3/cohend/), and the question of whether the reality of the data should be summarized in English as a "large difference" or a "small difference" becomes _much less interesting_, bordering on meaningless.

Murray also addresses the issue of aggregating effect sizes—something [I've been meaning to get around to blogging about](/2018/Dec/untitled-metablogging-26-december-2018/#high-dimensional-social-science-and-the-conjunction-of-small-effect-sizes) more exhaustively in this context of group differences (although at least, um, my favorite author on _Less Wrong_ [covered it in the purely abstract setting](https://www.lesswrong.com/posts/cu7YY7WdgJBs3DpmJ/the-univariate-fallacy)): small effect sizes in any single measurement (whatever "small" means) can amount to a _big_ difference when you're considering many measurements at once. That's how people can [distinguish female and male faces at 96% accuracy](http://unremediatedgender.space/papers/bruce_et_al-sex_discrimination_how_do_we_tell.pdf), even though there's no single measurement (like "eye width" or "nose height") offers that much predictive power.

Subsequent chapers address sex differences in personality, cognition, interests, and the brain. It turns out that women are more warm, empathetic, æsthetically discerning, and cooperative than men are! They're also more into the Conventional, Artistic, and Social dimensions of the [Holland occupational-interests model](https://en.wikipedia.org/wiki/Holland_Codes).

You might think that this is all due to socialization, but then it's hard to explain why the same differences show up in different cultures—and why (counterintuitively) the differences seem _larger_ in richer, more feminist countries. (Although as evolutionary anthropologist [William Buckner](https://traditionsofconflict.com/) points out in [his](https://twitter.com/Evolving_Moloch/status/1228124441944584192) [social-media](https://twitter.com/Evolving_Moloch/status/1228860328483491840) [criticism](https://twitter.com/Evolving_Moloch/status/1228947493309698050) of _Human Diversity_, [W.E.I.R.D.](https://www.apa.org/monitor/2010/05/weird) samples from different countries aren't capturing the full range of human cultures.) You might think that the "larger differences in rich countries" result is an artifact: maybe people in less-feminist countries implicitly make within-sex comparisons when answering personality questions (_e.g._, "I'm competitive _for a woman_") whereas people in more-feminist countries use a less sexist standard of comparison, construing ratings as compared to people-in-general. Murray points out that this explanation still posits the existence of large sex differences in rich countries (while explaining away the unexpected cross-cultural difference-in-differences). Another possibility is that sexual dimorphism _in general_ increases with wealth, including, _e.g._, in height and blood pressure, not just in personality. (I notice that this is consilient with the view that [agriculture was a mistake](https://www.discovermagazine.com/planet-earth/the-worst-mistake-in-the-history-of-the-human-race) that suppresses humans' natural tendencies, and that people [revert to forager-like lifestyles](http://www.overcomingbias.com/2010/10/divide-forager-v-farmer.html) [in many ways](http://www.overcomingbias.com/2017/08/forager-v-farmer-elaborated.html) as the riches of the industrial revolution let them afford it.)

Women are better at verbal ability and social cognition, whereas [men are better at visuospatial skills](http://zackmdavis.net/blog/2016/12/alpha-gamma-phi/). The sexes achieve similar levels of overall performance via somewhat different mental "toolkits." Murray devotes a section to a 2007 result of Johnson and Bouchard, who report that general intelligence ["masks the dimensions on which [sex differences in mental abilities] lie"](/papers/johnson-bouchard-sex_differences_in_mental_abilities_g_masks_the_dimensions.pdf): people's overall skill in using tools from the metaphorical mental toolbox leads to underestimates of differences in toolkits (that is, nonmetaphorically, the effect sizes of sex differences in specific mental abilities), which you want to statistically correct for. This result in particular is _super gratifying_ to me personally, because [I independently had a very similar idea a few months back](/2019/Sep/does-general-intelligence-deflate-standardized-effect-sizes-of-cognitive-sex-differences/)—it's _super validating_ as an amateur to find that the pros have been thinking along the same track!

The second part of the book is about some ways in which people with different ancestries are different from each other! Obviously, there are no "distinct" "races" (that would be dumb), but it turns out (as found by endeavors such as [Li _et al._ 2008](/papers/li_et_al-worldwide_human_relationships_inferred.pdf)) that when you throw clustering and [dimensionality-reduction](https://en.wikipedia.org/wiki/Dimensionality_reduction) algorithms at SNP data (<em>s</em>ingle <em>n</em>ucleotide <em>p</em>olymorphisms, places in the genome where more than one allele has non-negligible frequency), you get groupings that are a pretty good match to classical or self-identified "races".

Ask the computer to assume that an individual's ancestry came from _K_ fictive ancestral populations where _K_ := 2, and it'll infer that sub-Saharan Africans are descended entirely from one, East Asians and some native Americans are descended entirely from the other, and everyone else is an admixture. But if you set _K_ := 3, populations from Europe and the near East (which were construed as admixtures in the _K_ := 2 model) split off as a new inferred population cluster. And so on.

These ancestry groupings _are_ a "construct" in the sense that the groupings aren't "ordained by God"—the algorithm can find _K_ groupings for your choice of _K_—but _where_ it [draws those category boundaries](https://www.lesswrong.com/posts/d5NyJ2Lf6N22AD9PB/where-to-draw-the-boundary) is a function of the data. The construct is doing _cognitive work_, concisely summarizing statistical regularities in the dataset (which is _too large_ for humans to hold in their heads all at once): a map that reflects a territory.

Twentieth-century theorists like Fisher and Haldane and whatshisface-the-guinea-pig-guy had already figured out a lot about how evolution works (stuff like, a mutation that confers a fitness advantage of _s_ has a probability of about 2<em>s</em> of sweeping to fixation), but a lot of hypotheses about recent human evolution weren't easy to test or even formulate until the genome was sequenced!

You might think that there wasn't enough _time_ in the 2–5k generations since we came forth out of Africa for much human evolution to take place: a new mutation needs to confer an unusually large benefit to sweep to fixation that fast. But what if you didn't actually need any new mutations? Natural selection on polygenic traits can also act on "standing variation": variation _already_ present in the population that was mostly neutral in previous environments, but is fitness-relevant to new selection pressures. The rapid response to selective breeding observed in domesticated plants and animals mostly doesn't depend on new mutations.

Another mechanism of recent human evolution is _introgression_: early humans interbred with our Neanderthal and Denisovan "cousins", giving our lineage the chance to "steal" all their good alleles! In contrast to new mutations, which usually die out even when they're beneficial (that 2<em>s</em> rule again), alleles "flowing" from another population keep getting reintroduced, giving them more chances to sweep!

Population differences are important when working with genome-wide association studies, because a model "trained on" one population won't perform as well against the ["test set"](https://en.wikipedia.org/wiki/Training,_validation,_and_test_sets) of a different population. Suppose you do a big study and find a bunch of SNPs that correlate with a trait, like schizophrenia or liking opera. The frequencies of those SNPs for two populations from the same continent (like Japanese and Chinese) will hugely correlate (Pearson's _r_ ≈ 0.97), but for more genetically-distant populations from different continents, the correlation will still be big but not huge (like _r_ ≈ 0.8 or whatever).

What do these differences in SNP frequencies mean in practice?? We ... don't know yet. At least some population differences are fairly well-understood: I'd tell you about sickle-cell and lactase persistence, except [then I would have to scream](/2017/Dec/interlude-xi/). There are some cases where we see populations independently evolve different adaptations that solve the same problem: [people living on the plateaus of both Tibet and Peru have both adapted to high altitudes](https://www.pnas.org/content/104/suppl_1/8655.long), but the Tibetans did it by breathing faster and the Peruvians did it with more hemoglobin!

Sorry, "the Tibetans did it with ..." is sloppy phrasing on my part; what I actually mean is that the Tibetans who weren't genetically predisposed to breathe faster were more likely to die without leaving children behind. That's how evolution works!

The third part of the book is about genetic influences on class structure! Untangling the true causes of human variation is a really hard technical philosophy problem, but behavioral geneticists have at least gotten started with their simple _ACE_ model. It works like this: first, assume (that is, "pretend") that the genetic variation for a trait is _additive_ (if you have the appropriate SNP, you get more of the trait), rather than exhibiting _epistasis_ (where the effects of different loci interfere with each other) or Mendelian _dominance_ (where the presence of just one copy of an allele (of two) determines the phenotype, and it doesn't matter whether you heterozygously have a different allele as your second version of that gene). Then we pretend that we can partition the variance in phenotypes as the sum of the "additive" genetic variance _A_, plus the environmental variance "common" within a family _C_, plus "everything else" (including measurement "error" and the not-shared-within-families "environment") _E_. Briefly (albeit at the risk of being _cliché_): nature, nurture, and _noise_.

Then we can estimate the sizes of the _A_, _C_, and _E_ components by studying fraternal and identical twins. (If you hear people talking about "twin studies", this is what they mean—_not_ case studies of identical twins raised apart, which _are_ really cool but don't happen very often.) Both kinds of twins have the same family environment _C_ at the same time (parents, socioeconomic status, schools, _&c._), but identical twins are twice as genetically related to each other as fraternal twins, so the extent to which the identical twins are more similar is going to pretty much be because of their genes. "Pretty much" in the sense that while there are ways in which the assumptions of the model aren't quite true (assortative mating makes fraternal twins more similar in the ways their parents were _already_ similar before mating, identical twins might get treated more similarly by "the environment" on account of their appearance), the _quantitative_ effect of these deviations are probably pretty small!

Anyway, it turns out that the effect of the shared environment _C_ is way smaller than most people intuitively expect—next to zero for personality and adult intelligence. The environment matters—just not the part of the environment shared by sibling in the same family. Just not the part of the environment we know how to control. Thus, a lot of economic and class stratification actually ends up being along genetic lines: the nepotism of family wealth can buy opportunities and second chances, but it doesn't actually live your life for you.

<a id="heritability-caveats"></a>It's important not to overinterpret the heritability results; there are a bunch of standard caveats that go here that everyone's treatment of the topic needs to include! Heritability is about the _variance_ in phenotypes that can be predicted by _variance_ in genes. This is _not_ the same concept as "controlled by genes." To see this, notice that the trait "number of heads" has a heritability of zero because the variance is zero: all living people have exactly one head. (Siamese twins are two people.) Heritability estimates are also necessarily bound to a particular population in a particular place and time, which can face constraints shaped solely by the environment. If you plant half of a batch of seeds in the shade and half in the sun, the variance in the heights of the resulting plants will be associated with variance in genes _within_ each group, but the difference _between_ the groups is solely determined by the sunniness of their environments. Likewise, in a Society with a cruel caste system under which children with red hair are denied internet access, part of the heritability of intellectual achievement is going to come from alleles that code for red hair. Even though (_ex hypothesi_) redheads have the same inherent intellectual potential as everyone else, the heritability computation can't see into worlds that are not our own, which might have vastly different gene–environment correlations.

Old-timey geneticists used to think that they would find small number of "genes for" something, but it turns out that we live in an omnigenetic, pleiotropic world where lots and lots of SNPs each exert a tiny effect on potentially lots and lots of things. I feel like this probably _shouldn't_ have been surprising (genes code for amino-acid sequences, variation in what proteins get made from those amino-acid sequences is going to affect high-level behaviors, but high-level behaviors involve _lots_ of proteins in a super-complicated unpredictable way), but I guess it was.

Murray's penultimate chapter summarizes the state of a debate between a "Robert Plomin school" and an "Eric Turkheimer school" on the impact and import of polygenic scores, where we tally up all the SNPs someone has that are associated with a trait of interest.

The starry-eyed view epitomized by Plomin says that polygenic scores are _super great_ and everyone _and [her](/2020/Apr/the-reverse-murray-rule/) dog_ should be excited about them: they're causal in only one direction (the trait can't cause the score) and they let us assess risks in individuals before they happen. Clinical psychology will enter a new era of "positive genomics", where we understand how to work with the underlying dimensions along which people vary (including positively), rather than focusing on treated "diagnoses" that people allegedly "have".

The curmudgeonly view epitomized by Turkheimer says that Science is about understanding the _causal structure_ of phenomena, and that polygenic scores don't fucking tell us anything. [Marital status is heritable _in the same way_ that intelligence is heritable](http://www.geneticshumanagency.org/gha/the-ubiquity-problem-for-group-differences-in-behavior/), not because there are "divorce genes" in any meaningful biological sense, but because of a "universal, nonspecific genetic pull on everything": on average, people with more similar genes will make more similar proteins from those similar genes, and therefore end up with more similar phenotypes that interact with the environment in a more similar way, and _eventually_ (the causality flowing "upwards" through many hierarchical levels of organization) this shows up in the divorce statistics of a particular Society in a particular place and time. But this is opaque and banal; the real work of Science is in figuring out what all the particular gene variations actually _do_.

Notably, Plomin and Turkheimer aren't actually disagreeing here: it's a difference in emphasis rather than facts. Polygenic scores _don't_ explain mechanisms—but might they end up being useful, and used, anyway? Murray's vision of social science is content to make predictions and "explain variance" while remaining ignorant of ultimate causality. (Murray compares polygenic scores to "economic indexes predicting GDP growth", which is not necessarily a reassuring analogy to those who doubt how much of GDP represents real production rather than the "exhaust heat" of zero-sum contests in an environment of [manufactured scarcity](http://benjaminrosshoffman.com/there-is-a-war/) and [artificial demand](https://write.as/harold-lee/the-sliding-scale-of-bullshit-jobs).) Meanwhile, my cursory understanding (while kicking myself for [_still_](/2018/Dec/untitled-metablogging-26-december-2018/#daphne-koller-and-the-methods) not having put in the hours to get much farther into [_Probabilistic Graphical Models: Principles and Techniques_](https://mitpress.mit.edu/books/probabilistic-graphical-models)) was that you _need_ to understand causality in order to predict what interventions will have what effects: variance in rain may be statistically "explained by" variance in mud puddles, but you can't make it rain by turning the hose on. Maybe our feeble state of knowledge is _why_ we don't know how to find reliable large-effect environmental interventions that still yet might exist in the vastness of the space of possible interventions.

There are also some appendicies at the back of the book! Appendix 1 (reproduced from, um, one of Murray's earlier books with a coauthor) explains some basic statistics concepts. Appendix 2 ("Sexual Dimorphism in Humans") goes over the prevalence of intersex conditions and gays, and then—so much for this post broadening the [topic scope of this blog](/tag/two-type-taxonomy/)—transgender typology! Murray presents the Blanchard–Bailey–Lawrence–Littman view as fact, which I think is basically _correct_, but a more comprehensive treatment (which I concede may be too much too hope for from a mere Appendix) would have at least _mentioned_ alternative views ([Serano](https://rationalwiki.org/wiki/Intrinsic_Inclinations_Model)? [Veale](/papers/veale-lomax-clarke-identity_defense_model.pdf)?), if only to explain _why_ they're worth dismissing. (Contrast to the eight pages in the main text explaining why "But, but, epigenetics!" is worth dismissing.) Then Appendix 3 ("Sex Differences in Brain Volumes and Variance") has tables of brain-size data, and an explanation of the greater-male-variance hypothesis. Cool!

-----

... and that's the book review that I would _prefer_ to write. A science review of a science book, for science nerds: the kind of thing that would have no reason to draw your attention if you're not _genuinely interested_ in Mahanalobis _D_ effect sizes or adaptive introgression or Falconer's formulas, for their own sake, or (better) for the sake of [compressing the length of the message needed to encode your observations](https://en.wikipedia.org/wiki/Minimum_message_length).

But that's not why you're reading this. That's not why Murray wrote the book. That's not even why _I'm_ writing this. We should hope—emphasis on the _should_—for a discipline of Actual Social Science, whose practitioners strive to report the truth, the whole truth, and nothing but the truth, with the same passionately dispassionate objectivity they might bring to the study of beetles, or algebraic topology—or that an alien superintelligence might bring to the study of humans.

We do not have a discipline of Actual Social Science. Possibly because we're not smart enough to do it, but perhaps more so because we're not smart enough to _want_ to do it. No one has an incentive to lie about the homotopy groups of an _n_-sphere. If you're asking questions about homotopy groups _at all_, you almost certainly care about getting _the right answer for the right reasons_. At most, you might be biased towards believing your own conjectures in the optimistic hope of achieving eternal algebraic-topology fame and glory, like Ruth Lawrence. But nothing about algebraic topology is going to be [_morally threatening_](/2019/Jan/interlude-xvi/) in a way that will leave you fearing that your ideological enemies have siezed control of the publishing-houses to plant lies in the textbooks to fuck with your head, or sobbing that a malicious God created the universe as a place of evil.

Okay, maybe that was a bad example; topology in general really is the kind of mindfuck that might be the design of an adversarial agency. (Remind me to tell you about the long line, which is like the line of real numbers, except much longer.)

In any case, as soon as we start to ask questions _about humans_—and far more so _identifiable groups_ of humans—we end up entering the domain of _politics_.

We really _shouldn't_. Everyone _should_ perceive a common interest in true beliefs—maps that reflect the territory, [simple theories](https://www.lesswrong.com/posts/f4txACqDWithRi7hs/occam-s-razor) that [predict our observations](https://www.lesswrong.com/posts/a7n8GdKiAZRX86T5A/making-beliefs-pay-rent-in-anticipated-experiences)—because beliefs that make accurate predictions are _useful_ for making good decisions. That's what "beliefs" are _for_, evolutionarily speaking: my analogues in humanity's environment of evolutionary adaptedness were better off believing that (say) the berries from some bush were good to eat if and only if the berries were _actually_ good to eat. If my analogues unduly-optimistically thought the berries were good when they actually weren't, they'd get sick (and lose fitness), but if they unduly-pessimistically thought the berries were not good when they actually were, they'd miss out on valuable calories (and fitness).

(Okay, this story is actually somewhat complicated by the fact that [evolution didn't "figure out" how to build brains](https://www.lesswrong.com/posts/gTNB9CQd5hnbkMxAG/protein-reinforcement-and-dna-consequentialism) that [keep track of probability and utility separately](https://plato.stanford.edu/entries/decision-theory/): my analogues in the environment of evolutionary adaptedness might also have been better off assuming that a rustling in the bush was a tiger, even if it usually wasn't a tiger, because failing to detect actual tigers was so much more costly than erroneously "detecting" an imaginary tiger. But let this pass.)

The problem is that, while any individual should always want true beliefs for _themselves_ in order to navigate the world, you might want _others_ to have false beliefs in order to trick them into _mis_-navigating the world in a way that benefits you. If I'm trying to sell you a used car, then—counterintuitively—I might not _want_ you to have accurate beliefs about the car, if that would reduce the sale price or result in no deal. If our analogues in the environment of evolutionary adaptedness regularly faced structurally similar situations, and if it's expensive to maintain two sets of beliefs (the real map for ourselves, and a fake map for our victims), we might end up with a tendency not just to be lying motherfuckers who decieve others, but also to _self_-decieve in situations where the fitness payoffs of tricking others outweighed those of being clear-sighted ourselves.

That's why we're not smart enough to want a discipline of Actual Social Science. The benefits of having a collective understanding of human behavior—a _shared_ map that reflects the territory that we are—could be enormous, but beliefs about our own qualities, and those of socially-salient groups to which we belong (_e.g._, sex, race, and class) are _exactly_ those for which we face the largest incentive to decieve and self-decieve. Counterintuively, I might not _want_ you to have accurate beliefs about the value of my friendship (or the disutility of my animosity), for the same reason that I might not want you to have accurate beliefs about the value of my used car. That makes it a lot harder not just to _get the right answer for the reasons_, but also to _trust_ that your fellow so-called "scholars" are trying to get the right answer, rather than trying to sneak self-aggrandizing lies into the shared map in order to fuck you over. You can't _just_ write a friendly science book for oblivious science nerds about "things we know about some ways in which people are different from each other", because almost no one is that oblivious. To write and be understood, you have to do some sort of _positioning_ of how your work fits in to [the war](/2020/Feb/if-in-some-smothering-dreams-you-too-could-pace/) over the shared map.

Murray positions _Human Diversity_ as a corrective to a "blank slate" orthodoxy that refuses to entertain any possibility of biological influences on psychological group differences. The three parts of the book are pitched not simply as "stuff we know about biologically-mediated group differences" (the oblivious-science-nerd approach that I would prefer), but as a rebuttal to "Gender Is a Social Construct", "Race Is a Social Construct", and "Class Is a Function of Privilege." At the same time, however, Murray is careful to position his work as _nonthreatening_: "there are no monsters in the closet," he writes, "no dread doors that we must fear opening." He likewise "state[s] explicitly that [he] reject[s] claims that groups of people, be they sexes or races or classes, can be ranked from superior to inferior [or] that differences among groups have any relevance to human worth or dignity."

I think this strategy is sympathetic but [ultimately ineffective](http://zackmdavis.net/blog/2016/08/ineffective-deconversion-pitch/). Murray is trying to have it both ways: challenging the orthodoxy, while denying the possibility of any [unfortunate implications](https://tvtropes.org/pmwiki/pmwiki.php/Main/UnfortunateImplications) of the orthodoxy being false. It's like ... [theistic evolution](https://en.wikipedia.org/wiki/Theistic_evolution): satisfactory as long as you _don't think about it too hard_, but among those with a high [need for cognition](https://en.wikipedia.org/wiki/Need_for_cognition), who know what it's like to truly believe (as I once believed), it's not going to convince anyone who hasn't _already_ broken from the orthodoxy.

Murray concludes, "Above all, nothing we learn will threaten human equality properly understood." I _strongly_ agree with the _moral sentiment_, the underlying [axiology](https://slatestarcodex.com/2017/08/28/contra-askell-on-moral-offsets/) that makes this seem like a good and wise thing to say.

And yet I have been ... [trained](https://www.lesswrong.com/posts/teaxCFgtmCQ3E9fy8/the-martial-art-of-rationality). Trained to instinctively apply my full powers of analytical rigor and skepticism [to even that which is most sacred](https://www.lesswrong.com/posts/dHQkDNMhj692ayx78/avoiding-your-belief-s-real-weak-points). Because my true loyalty is to the axiology—[to the _process_ underlying my _current best guess_](http://zackmdavis.net/blog/2017/03/dreaming-of-political-bayescraft/) as to that which is most sacred. If that which was believed to be most sacred turns out to not be entirely coherent ... then we might have some philosophical work to do, to [_reformulate_ the sacred moral ideal in a way that's actually coherent](https://arbital.greaterwrong.com/p/rescue_utility).

"Nothing we learn will threaten _X_ _properly understood_." When you elide the specific assignment _X_ := "human equality", the _form_ of this statement is kind of suspicious, right? Why "properly understood"? It would be weird to say, "Nothing we learn will threaten the homotopy groups of an _n_-sphere _properly understood_."

This kind of [claim to be non-disprovable](https://www.lesswrong.com/posts/fAuWLS7RKWD2npBFR/religion-s-claim-to-be-non-disprovable) seems like the kind of thing you would only invent if you _were_ secretly worried about _X_ being threatened by new discoveries, and wanted to protect your ability to backtrack and [re-gerrymander your definition of _X_ to protect what you](https://www.lesswrong.com/posts/esRZaPXSHgWzyB2NL/where-to-draw-the-boundaries) ([think that you](https://www.lesswrong.com/posts/CqyJzDZWvGhhFJ7dY/belief-in-belief)) currently believe.

If being an oblivious science nerd isn't an option, half-measures won't suffice. I think we can do better by going meta and analyzing the _functions_ being served by the constraints on our discourse and seeking out clever self-aware strategies for satisfying those functions _without_ [lying about everything](/2017/Jan/im-sick-of-being-lied-to/). We mustn't fear opening the dread meta-door in front of whether there actually _are_ dread doors that we must fear opening.

Why _is_ the blank slate doctrine so compelling, that so many feel the need to protect it at all costs? (As I once felt the need.) It's not ... if you've read this far, I assume you _will_ forgive me—it's not _scientifically_ compelling. If you were studying humans the way an alien superintelligence would, trying to _get the right answer for the right reasons_ (which can conclude _conditional_ answers: if what humans are like depends on _choices_ about what we teach our children, then there will still be a fact of the matter as to what choices lead to what outcomes), you wouldn't put a whole lot of prior probability on the hypothesis "Both sexes and all ancestry-groupings of humans have the same distribution of psychological predispositions; any observed differences in behavior are solely attributable to differences in their environments." _Why_ would that be true? We _know_ that sexual dimorphism exists. We _know_ that reproductively isolated populations evolve different traits to adapt to their environments, like [those birds with differently-shaped beaks that Darwin saw on his boat trip](https://en.wikipedia.org/wiki/Darwin%27s_finches). We could certainly _imagine_ that none of the relevant selection pressures on humans happened to touch the brain—but why? Wouldn't that be kind of a weird coincidence?

If the blank slate doctrine isn't _scientifically_ compelling—it's not something you would invent while trying to build shared maps that reflect the territory—then its appeal must have something to do with some function it plays in _conflicts_ over the shared map, where no one trusts each other to be doing Actual Social Science rather than lying to fuck everyone else over.

And that's where the blank slate doctrine absolutely _shines_—it's the [Schelling point](/2019/Oct/self-identity-is-a-schelling-point/#schelling-point) for preventing group conflicts! (A [_Schelling point_](https://www.lesswrong.com/posts/yJfBzcDL9fBHJfZ6P/nash-equilibria-and-schelling-points) is a choice that's salient as [a focus for mutual expectations](/2019/Dec/more-schelling/): what I think that you think that I think ... _&c._ we'll choose.) If you admit that there could differences between groups, you open up the questions of in what exact traits and of what exact magnitude, which people have an incentive to lie about to divert resources and power to their group by [establishing unfair conventions and then misrepresenting those contingent bargaining equilibria](/2020/Jan/book-review-the-origins-of-unfairness/) as some "inevitable" natural order.

If you're afraid of purported answers being used as a pretext for oppression, you might hope to _make the question un-askable_. Can't oppress people on the basis of race if race _doesn't exist_! Denying the existence of sex is harder—which doesn't stop people from occasionally trying. "I realize I am writing in an LGBT era when some argue that 63 distinct genders have been identified," Murray notes at the beginning of Appendix 2. But this oblique acerbity fails to pass the [Ideological Turing Test](https://www.econlib.org/archives/2011/06/the_ideological.html). The language of _has been identified_ suggests an attempt at scientific taxonomy—a project, which I share with Murray, of fitting categories to describe a preexisting objective reality. But I don't think the people making 63-item typeahead select "Gender" fields for websites are thinking in such terms to begin with. The specific number 63 [is ridiculous and can't exist](/2019/Dec/on-the-argumentative-form-super-proton-things-tend-to-come-in-varieties/); it might as well be, and often is, a fill-in-the-blank free text field. Despite being insanely evil (where I mean the adjective literally rather than as a generic intensifier—evil in a way that is of or related to insanity), I must acknowledge this is at least good game theory. If you don't trust taxonomists to be acting in good faith—if you think we're trying to bulldoze the territory to fit a preconcieved map—then [destroying the language](/2019/Aug/the-social-construction-of-reality-and-the-sheer-goddamned-pointlessness-of-reason/#re-collapse-the-sex-gender-distinction) that would be used to be build oppressive maps is a smart move.

The taboo mostly only applies to _psychological_ trait differences, because those are a [sensitive subject](http://benjaminrosshoffman.com/judgment-punishment-and-the-information-suppression-field/)—and easier to motivatedly _see what you want to see_: whereas things like height or skin tone can be directly seen and uncontroversially measured with well-understood physical instruments (like a meterstick or digital photo pixel values), psychological assessments are _much_ more complicated and therefore hard to detach from the eye of the beholder. (If I describe Mary as "warm, compassionate, and agreeable", the words mean _something_ in the sense that they change what experiences you anticipate—if you believed my report, you would be _surprised_ if Mary were to kick your dog and make fun of your nose job—but the things that they mean are a high-level statistical signal in behavior for which we [don't have a simple measurement device](https://www.lesswrong.com/posts/edEXi4SpkXfvaX42j/schelling-categories-and-simple-membership-tests) like a meterstick to appeal to if you and I don't trust each other's character assessments of Mary.)

Notice how the "not allowing sex and race differences in psychological traits to appear on shared maps is the Schelling point for resistance to sex- and race-based oppression" actually gives us an _explanation_ for _why_ one might reasonably have a sense that there are dread doors that we must not open. Undermining the "everyone is Actually Equal" Schelling point could [catalyze a preference cascade](https://www.reddit.com/r/slatestarcodex/comments/8q8p6n/culture_war_roundup_for_june_11/e0mxwe9/)—a [slide down the slippery slope to the the next Schelling point](https://www.lesswrong.com/posts/Kbm6QnJv9dgWsPHQP/schelling-fences-on-slippery-slopes), which might be a lot worse than the _status quo_ on the "amount of rape and genocide" metric, even if it does slightly better on "estimating heritability coefficients." The orthodoxy isn't just being dumb for no reason. In analogy, Galileo and Darwin weren't _trying_ to undermine Christianity—they had much more interesting things to think about—but religious authorities were _right_ to fear heliocentrism and evolution: if the prevailing coordination equilibrium depends on lies, then telling the truth _is_ a threat and it _is_ disloyal. And if the prevailing coordination equilibrium is basically _good_, then you can see why purported truth-tellers striking at the heart of the faith might be believed to be evil.

Murray opens the parts of the book about sex and race with acknowledgements of the injustice of historical patriarchy ("When the first wave of feminism in the United States got its start [...] women were rebelling not against mere inequality, but against near-total legal subservience to men") and racial oppression ("slavery experienced by Africans in the New World went far beyond legal constraints [...] The freedom granted by emancipation in America was only marginally better in practice and the situation improved only slowly through the first half of the twentieth century"). It feels ... defensive? Coerced? It probably _is_ coerced. (To his credit, Murray is generally pretty forthcoming about how the need to write "defensively" shaped the book, as in a sidebar in the introduction that says that he's prefer to say a lot more about evopsych, but he chose to just focus on empirical findings in order to avoid the charge of telling [just-so stories](https://en.wikipedia.org/wiki/Just-so_story).)

But this kind of defensive half-measure satisfies no one. From the oblivious-science-nerd perspective—the view that agrees with Murray that "everyone should calm down"—you shouldn't _need_ to genuflect to the memory of some historical injustice before you're allowed to talk about Science. But from the perspective that cares about Justice and not just Truth, an _insincere_ gesture or a strategic concession is all the more dangerous insofar as it could function as camoflage for a nefarious hidden agenda. If your work is explicitly aimed at _destroying the anti-oppression Schelling-point belief_, a few hand-wringing historical interludes and bromides about human equality having no testable implications (!!) aren't going to clear you of the suspicion that you're _doing it on purpose_—trying to destroy the anti-oppression Schelling point in order to oppress, and not because anything that can be destroyed by the truth, should be.

And sufficient suspicion makes communication nearly impossible. (If you _know_ someone is lying, their words mean nothing, [not even as the opposite of the truth](https://www.lesswrong.com/posts/qNZM3EGoE5ZeMdCRt/reversed-stupidity-is-not-intelligence).) As far as many of Murray's detractors are concerned, it almost doesn't matter what the text of _Human Diversity_ says, how meticulously researched of a psychology/neuroscience/genetics lit review it is. From their perspective, Murray is "hiding the ball": they're not mad about _this_ book; they're mad about specifically chapters 13 and 14 of a book Murray coauthored twenty-five years ago. (I don't think I'm claiming to be a mind-reader here; the first 20% of [_The New York Times_'s review of _Human Diversity_](https://archive.is/b4xKB) is pretty explicit and representative.)

In 1994's _The Bell Curve: Intelligence and Class Structure in American Life_, Murray and coauthor Richard J. Herrnstein argued that a lot of variation in life outcomes is explained by variation in intelligence. Some people think that folk concepts of "intelligence" or being "smart" are ill-defined and therefore not a proper object of scientific study. But that hasn't stopped some psychologists from trying to construct tests purporting to measure an "intelligence quotient" (or _IQ_ for short). It turns out that if you give people a bunch of different mental tests, the results all positively correlate with each other: people who are good at one mental task, like listening to a list of numbers and repeating them backwards ("reverse digit span"), are also good at others, like knowing what words mean ("vocabulary"). There's a lot of fancy linear algebra involved, but basically, you can visualize people's test results as a hyper[ellipsoid](https://en.wikipedia.org/wiki/Ellipsoid) in some high-dimensional space where the dimensions are the different tests. (I rely on this ["configuration space"](https://www.lesswrong.com/posts/WBw8dDkAWohFjWQSk/the-cluster-structure-of-thingspace) visual metaphor _so much_ for _so many_ things that when I started [my secret ("secret") gender blog](/), it felt right to put it under a `.space` [TLD](https://en.wikipedia.org/wiki/Top-level_domain).) The longest axis of the hyperellipsoid corresponds to the "_g_ factor" of "general" intelligence—the choice of axis that cuts through the most variance in mental abilities.

It's important not to overinterpret the _g_ factor as some unitary essence of intelligence rather than the length of a hyperellipsoid. It seems likely that [if you gave people a bunch of _physical_ tests, they would positively correlate with each other](https://www.talyarkoni.org/blog/2010/03/07/what-the-general-factor-of-intelligence-is-and-isnt-or-why-intuitive-unitarianism-is-a-lousy-guide-to-the-neurobiology-of-higher-cognitive-ability/), such that you could extract a ["general factor of athleticism"](https://isteve.blogspot.com/2007/09/g-factor-of-sports.html). (It would be really interesting if anyone's actually done this using the same methodology used to construct IQ tests!) But _athleticism_ is going to be an _very_ "coarse" construct for which [the tails come apart](https://www.lesswrong.com/posts/dC7mP5nSwvpL65Qu5/why-the-tails-come-apart): for example, world champion 100-meter sprinter Usain Bolt's best time in the _800_ meters is [reportedly only around 2:10](https://www.newyorker.com/sports/sporting-scene/how-fast-would-usain-bolt-run-the-mile) [or 2:07](https://archive.is/T988h)! (For comparison, _I_ ran a 2:08.3 in high school once!)

Anyway, so Murray and Herrnstein talk about this "intelligence" construct, and how it's heritable, and how it predicts income, school success, not being a criminal, _&c._, and how Society is becoming increasingly stratified by cognitive abilities, as school credentials become the ticket to the upper and upper-middle classes.

This _should_ just be more social-science nerd stuff, the sort of thing that would only draw your attention if, like me, you feel bad about not being smart enough to do algebraic topology and want to console yourself by at least knowing about the Science of not being smart enough to do algebraic topology. The reason everyone _and her dog_ is still mad at Charles Murray a quarter of a century later is Chapter 13, "Ethnic Differences in Cognitive Ability", and Chapter 14, "Ethnic Inequalities in Relation to IQ". So, _apparently_, different ethnic/"racial" groups have different average scores on IQ tests. [Ashkenazi Jews do the best](https://slatestarcodex.com/2017/05/26/the-atomic-bomb-considered-as-hungarian-high-school-science-fair-project/), which is why I sometimes privately joke that the fact that I'm [only 85% Ashkenazi (according to 23andMe)](/images/ancestry_report.png) explains my low IQ. ([I got a 131](/images/wisc-iii_result.jpg) on the [WISC-III](https://en.wikipedia.org/wiki/Wechsler_Intelligence_Scale_for_Children) at age 10, but that's pretty dumb compared to some of my [robot-cult](/tag/my-robot-cult/) friends.) East Asians do a little better than Europeans/"whites". And—this is the part that no one is happy about—the difference between U.S. whites and U.S. blacks is about Cohen's _d_ ≈ 1. (If two groups differ by _d_ = 1 on some measurement that's normally distributed within each group, that means that the mean of the group with the lower average measurement is at the 16th percentile of the group with the higher average measurement, or that a uniformly-randomly selected member of the group with the higher average measurement has a probability of about 0.76 have having a higher measurement than a uniformly-randomly selected member of the group with the lower average measurement.)

Given the tendency for people to distort shared maps for political reasons, you can see why this is a hotly contentious line of research. Even if you take the test numbers at face value, racists trying to secure unjust privileges for groups that score well, have an incentive to "play up" group IQ differences in bad faith even when they shouldn't be [relevant](https://www.lesswrong.com/posts/GSz8SrKFfW7fJK2wN/relevance-norms-or-gricean-implicature-queers-the-decoupling). As economist Glenn C. Loury points out in _The Anatomy of Racial Inequality_, cognitive abilities decline with _age_, and yet we don't see a moral panic about the consequences of an aging workforce, because older people are construed as an "us"—our mothers and fathers—rather than an outgroup. _Individual_ differences in intelligence are also presumably less politically threatening because "smart people" as a group aren't construed as a natural political coalition—although Murray's work on cognitive class stratification would seem to suggest this intuition is mistaken.

It's important not to overinterpret the IQ-scores-by-race results; there are a bunch of standard caveats that go here that everyone's treatment of the topic needs to include. Again, just because variance in a trait is statistically associated with variance in genes _within_ a population, does _not_ mean that differences in that trait _between_ populations are _caused_ by genes: [remember the illustrations about](#heritability-caveats) sun-deprived plants and internet-deprived red-haired children. Group differences in observed tested IQs are entirely compatible with a world in which those differences are entirely due to the environment imposed by an overtly or structurally racist society. Maybe the tests are culturally biased. Maybe people with higher socioeconomic status get more opportunities to develop their intellect, and racism impedes socio-economic mobility. And so on.

The problem is, a lot of the blank-slatey environmentally-caused-differences-only hypotheses for group IQ differences start to look less compelling when you look into the details. "Maybe the tests are biased", for example, isn't an insurmountable defeater to the entire endeavor of IQ testing—it is _itself_ a falsifiable hypothesis, or can become one if you specify what you mean by "bias" in detail. One idea of what it would mean for a test to be _biased_ is if it's partially measuring something other than what it purports to be measuring: if your test measures a _combination_ of "intelligence" and "submission to the hegemonic cultural dictates of the test-maker", then individuals and groups that submit less to your cultural hegemony are going to score worse, and if you _market_ your test as unbiasedly measuring intelligence, then people who believe your marketing copy will be misled into thinking that those who don't submit are dumber than they really are. But if so, and if not all of your individual test questions are _equally_ loaded on intelligence and cultural-hegemony, then the cultural bias should _show up in the statistics_. If some questions are more "fair" and others are relatively more culture-biased, then you would expect the _order of item difficulties_ to differ by culture: the ["item characteristic curve"](/papers/baker-kim-the_item_characteristic_curve.pdf) plotting the probability of getting a biased question "right" as a function of _overall_ test score should differ by culture, with the hegemonic group finding it "easier" and others finding it "harder". Conversely, if the questions that discriminate most between differently-scoring cultural/ethnic/"racial" groups were the same as the questions that discriminate between (say) younger and older children _within_ each group, that would be the kind of statistical clue you would expect to see if the test was unbiased and the group difference was real.

Hypotheses that accept IQ test results as unbiased, but attribute group differences in IQ to the environment, also make statistical predictions that can be falsified. Controlling for parental socioeconomic status only cuts the black–white gap by a third. (And note, on the hereditarian model, some of the correlation between parental SES and child outcomes is due to both being causally downstream of genes.) The mathematical relationship between between-group and within-group heritability means that the conjunction of wholly-environmentally-caused group differences, and the within-group heritability, makes quantitative predictions about how much the environments of the groups differ. Skin color is actually only controlled by a small number of alleles, so if you think Society's discrimination on skin color causes IQ differences, you could maybe design a clever study that measures both overall-ancestry and skin color, and does statistics on what happens when they diverge. And so on.

In mentioning these arguments in passing, I'm _not_ trying to provide a comprehensive lit review on the causality of group IQ differences. (That's [someone else's blog](https://humanvarieties.org/2019/12/22/the-persistence-of-cognitive-inequality-reflections-on-arthur-jensens-not-unreasonable-hypothesis-after-fifty-years/).) I'm not that interested in this particular topic, and [without having mastered the technical literature, my assessment would be of little value](https://www.gwern.net/Mistakes#mu). Rather, I am ... doing some context-setting for the problem I _am_ interested in, of fixing public discourse. The reason we can't have an intellectually-honest public discussion about human biodiversity is because good people want to respect the anti-oppression Schelling point and are afraid of giving ammunition to racists and sexists in the war over the shared map. "Black people are, on average, genetically less intelligent than white people" is the kind of sentence that pretty much only racists would feel _good_ about saying out loud, independently of its actual truth value. In a world where most speech is about manipulating shared maps for political advantage rather than _getting the right answer for the right reasons_, it is _rational_ to infer that anyone who entertains such hypotheses is either motivated by racial malice, or is at least complicit with it—and that rational expectation isn't easily cancelled with a _pro forma_ "But, but, civil discourse" or "But, but, the true meaning of Equality is unfalsifiable" [disclaimer](http://www.overcomingbias.com/2008/06/against-disclai.html).

To speak to those who aren't _already_ oblivious science nerds—or are committed to emulating such, as it is scientifically dubious whether anyone is really that oblivious—you need to put _more effort_ into your excuse for why you're interested in these topics. Here's mine, and it's from the heart, though it's up to the reader to judge for herself how credible I am when I say this—

I don't want to be complicit with hatred or oppression. I want to stay loyal to the underlying egalitarian–individualist axiology that makes the blank slate doctrine _sound like a good idea_. But I also want to understand reality, to make sense of things. I want a world that's not lying to me. Having to believe false things—or even just not being able _say_ certain true things when they would otherwise be relevant—extracts a _dire_ cost on our ability to make sense of the world, because you can't just censor a few forbidden hypotheses—[you have to censor everything that _implies_ them](https://www.lesswrong.com/posts/wyyfFfaRar2jEdeQK/entangled-truths-contagious-lies), and everything that implies _them_: the more adept you are at making logical connections, [the more of your mind you need to excise to stay in compliance](https://www.lesswrong.com/posts/XTWkjCJScy2GFAgDt/dark-side-epistemology).

We can't talk about group differences, for fear that anyone arguing that differences exist is just trying to shore up oppression. But ... structural oppression and actual group differences can _both exist at the same time_. They're not contradicting each other! Like, the fact that men are physically stronger than women (on average, but the effect size is enormous, like _d_ ≈ 2.6 for total muscle mass) is _not unrelated_ to the persistence of patriarchy! (The ability to _credibly threaten_ to physically overpower someone, [gives the more powerful party a bargaining advantage](/2020/Jan/book-review-the-origins-of-unfairness/#threatpoints-and-bargaining), even if the threat is typically unrealized.) That doesn't mean patriarchy is good; to think so would be to commit the [naturalistic fallacy](https://plato.stanford.edu/entries/moral-non-naturalism/#NatFal) of [attempting to derive an _ought_ from an _is_](https://plato.stanford.edu/entries/hume-moral/#io). No one would say that famine and plague are good just because they, too, are subject to scientific explanation. This is pretty obvious, really? But similarly, genetically-mediated differences in cognitive repertoires between ancestral populations are probably going to be _part_ of the explanation for _why_ we see the particular forms of inequality and oppression that we do, just as a brute fact of history devoid of any particular moral significance, like how part of the explanation for why European conquest of the Americas happened earlier and went smoother for the invaders than the colonization of Africa had to do with the disease burden going the other way (Native Americans were particularly vulnerable to smallpox, but Europeans were particularly vulnerable to malaria).

Again—obviously—_is_ does not imply _ought_. In deference to the historicially well-justified egalitarian fear that such hypotheses will primarily be abused by bad actors to portray their own group as "superior", I find it helpful to dwell on science-fictional scenarios in which the boot of history is one's own neck. If a race of lavender humans from an alternate dimension were to come through a wormhole and invade our Earth and cruelly subjugate _your_ people, you would probably be pretty angry, and maybe join a paramilitary group aimed at overthrowing lavender supremacy and re-instanting civil rights. The possibility of a partially-biological _explanation_ for _why_ the purple bastards discovered wormhole generators when we didn't (maybe they have _d_ ≈ 1.8 on us in visuospatial skills, enabling their population to be first to "roll" a lucky genius who could discover the wormhole field equations), would not make the conquest somehow justified.

I don't know how to build a better world, but it seems like there are quite _general_ grounds on which we should expect that it would be helpful to be able to _talk_ about social problems in the language of cause and effect, with the austere objectivity of an engineering discipline. If you want to build a bridge (that will actually stay up), you need to study the ["the careful textbooks \[that\] measure \[...\] the load, the shock, the pressure \[that\] material can bear."](http://www.kiplingsociety.co.uk/poems_strain.htm) If you want to build a just Society (that will actually stay up), you need a discipline of Actual Social Science that can publish textbooks, and to get _that_, you need the ability to _talk_ about basic facts about human existence and make simple logical and statistical inferences between them.

And no one can do it! [("Well for us, if even we, even for a moment, can get free our heart, and have our lips unchained—for that which seals them hath been deep-ordained!")](https://www.poetryfoundation.org/poems/43585/the-buried-life) Individual scientists can get results in their respective narrow disciplines; Charles Murray can just _barely_ summarize the science to a semi-popular audience without coming off as _too_ overtly evil to modern egalitarian moral sensibilities. (At least, the smarter egalitarians? Or, maybe I'm just old.) But at least a couple aspects of reality are even _worse_ (with respect to naïve, non-renormalized egalitarian moral sensibilities) than the ball-hiders like Murray can admit, having already blown their entire [Overton budget](https://www.lesswrong.com/posts/DoPo4PDjgSySquHX8/heads-i-win-tails-never-heard-of-her-or-selective-reporting) explaining the relevant empirical findings.

Murray approvingly quotes Steven Pinker (a fellow ball-hider, though [Pinker is better at it](https://archive.is/bNo2q)): "Equality is not the empirical claim that all groups of humans are interchangeable; it is the moral principle that individuals should not be judged or constrained by the average properties of their group."

A fine sentiment. I _emphatically_ agree with the _underlying moral intuition_ that makes "Individuals should not be judged by group membership" _sound like_ a correct moral principle—one cries out at the _monstrous injustice_ of the individual being oppressed on the basis of mere stereotypes of what other people who _look_ like them might statistically be like.

But can I take this _literally_ as the _exact_ statement of a moral principle? _Technically?_—no! That's actually not how epistemology works! The proposed principle derives its moral force from the case of complete information: if you _know for a fact_ that I have moral property P, then it would be monstrously unjust to treat me differently just because other people who look like me mostly don't have moral property P. But in the real world, we often—usually—don't _have_ complete information about people, [or even about ourselves](/2016/Sep/psychology-is-about-invalidating-peoples-identities/).

Bayes's theorem (just [a few inferential steps away from the definition of conditional probability itself](https://en.wikipedia.org/wiki/Bayes%27_theorem#Derivation), barely worthy of being called a "theorem") states that for hypothesis H and evidence E, P(H|E) = P(E|H)P(H)/P(E). This is [the fundamental equation](https://www.readthesequences.com/An-Intuitive-Explanation-Of-Bayess-Theorem) [that governs](https://www.readthesequences.com/A-Technical-Explanation-Of-Technical-Explanation) [all thought](https://www.lesswrong.com/posts/QrhAeKBkm2WsdRYao/searching-for-bayes-structure). When you think you see a tree, that's really just your brain computing a high value for the probability of your sensory experiences given the hypothesis that there is a tree multiplied by the prior probability that there is a tree, as a fraction of all the possible worlds that could be generating your sensory experiences.

What goes for seeing trees, goes the same for "treating individuals as individuals": the _process_ of getting to know someone as an individual, involves exploiting the statistical relationships between what you observe, and what you're trying to learn about. If you see someone wearing an Emacs tee-shirt, you're going to assume that they _probably_ use Emacs, and asking them about their [dot-emacs file](https://www.gnu.org/software/emacs/manual/html_node/emacs/Init-File.html) is going to seem like a better casual conversation-starter compared to the base rate of people wearing non-Emacs shirts. Not _with certainty_—maybe they just found the shirt in a thrift store and thought it looked cool—but the shirt _shifts the probabilities_ implied by your decisionmaking.

The problem that Bayesian reasoning poses for naïve egalitarian moral intuitions, is that, as far as I can tell, there's no _philosophically principled_ reason for "probabilistic update about someone's psychology on the evidence that they're wearing an Emacs shirt" to be treated _fundamentally_ differently from "probabilistic update about someone's psychology on the evidence that she's female". These are of course different questions, but to a Bayesian reasoner (an inhuman mathematical abstraction for _getting the right answer_ and nothing else), they're the same _kind_ of question: the "correct" update to make is an _empirical_ matter that depends on the actual distribution of psychological traits among Emacs-shirt-wearers and among women. (In the possible world where _most_ people wear tee-shirts from the thrift store that looked cool without knowing what they mean, the "Emacs shirt → Emacs user" inference would usually be wrong.) But to a naïve egalitarian, judging someone on their expressed affinity for Emacs is good, but judging someone on their sex is _bad and wrong_.

I used to be a naïve egalitarian. I was very passionate about it. I was eighteen years old. I am—again—still fond of the moral sentiment, and eager to renormalize it into something that makes sense. (Some egalitarian anxieties do translate perfectly well into the Bayesian setting, as I'll explain in a moment.) But the abject horror I felt at eighteen at the mere suggestion of _making generalizations_ about _people_ just—doesn't make sense. Not that it _shouldn't_ be practiced (it's not that my heart wasn't in the right place), but that it _can't_ be practiced—that the people who think they're practicing it are just confused about how their own minds work.

Give people photographs of various women and men and ask them to judge how tall the people in the photos are, as [Nelson _et al._ 1990 did](/papers/nelson_et_al-everyday_base_rates_sex_stereotypes_potent_and_resilient.pdf), and people's guesses reflect both the photo-subjects' actual heights, but also (to a lesser degree) their sex. Unless you expect people to be perfect at assessing height from photographs (when they don't know how far away the cameraperson was standing, aren't ["trigonometrically omniscient"](https://plato.stanford.edu/entries/logic-epistemic/#LogiOmni), _&c._), this behavior is just _correct_: men really are taller than women on average, so P(true-height|apparent-height, sex) ≠ P(height|apparent-height) [because of](https://humanvarieties.org/2017/07/01/measurement-error-regression-to-the-mean-and-group-differences/) [regression to the mean](https://en.wikipedia.org/wiki/Regression_toward_the_mean) (and women and men regress to different means). But [this all happens subconsciously](/2020/Apr/peering-through-reverent-fingers/): in the same study, when the authors tried height-matching the photographs (for every photo of a woman of a given height, there was another photo in the set of a man of the same height) _and telling_ the participants about the height-matching _and_ offering a cash reward to the best height-judge, more than half of the stereotyping effect remained. It would seem that people can't consciously readjust their learned priors in reaction to verbal instructions pertaining to an artificial context.

Once you understand at a _technical_ level that probabilistic reasoning about demographic features is both epistemically justified, _and_ implicitly implemented as part of the way your brain processes information _anyway_, then a moral theory that forbids this starts to look less compelling? Of course, statistical discrimination on demographic features is only epistemically justified to exactly the extent that it helps _get the right answer_. Renormalized-egalitarians can still be properly outraged about the monstrous tragedies where I have moral property P but I _can't prove it to you_, so you instead guess _incorrectly_ that I don't just because other people who look like me mostly don't, and you don't have any better information to go on—or tragedies in which a feedback loop between predictions and social norms creates or amplifies group differences that wouldn't exist under some other social equilibrium.

Nelson _et al._ also found that when the people in the photographs were pictured sitting down, then judgements of height depended much more on sex than when the photo-subjects were standing. This too makes Bayesian sense: if it's harder to tell how tall an individual is when they're sitting down, you rely more on your demographic prior. In order to reduce injustice to people who are an outlier for their group, one could argue that there's a moral imperative to seek out interventions to get more fine-grained information about individuals, so that we don't need to rely on the coarse, vague information embodied in demographic stereotypes. The _moral spirit_ of egalitarian–individualism mostly survives in our efforts to [hug the query](https://www.lesswrong.com/posts/2jp98zdLo898qExrr/hug-the-query) and get [specific information](/2017/Nov/interlude-x/) with which to discriminate amongst individuals. (And _discriminate_—[to distinguish, to make distinctions](https://en.wiktionary.org/wiki/discriminate)—is the correct word.) If you care about someone's height, it is _better_ to precisely measure it using a meterstick than to just look at them standing up, and it is better to look at them standing up than to look at them sitting down. If you care about someone's skills as potential employee, it is _better_ to give them a work-sample test that assesses the specific skills that you're interested in, than it is to rely on a general IQ test, and it's _far_ better to use an IQ test than to use mere stereotypes. If our means of measuring individuals aren't reliable or cheap enough, such that we still end up using prior information from immutable demographic categories, that's a problem of grave moral seriousness—but in light of the [_mathematical laws_](https://www.lesswrong.com/posts/eY45uCCX7DdwJ4Jha/no-one-can-exempt-you-from-rationality-s-laws) governing reasoning under uncertainty, it's a problem that realistically needs to be solved with _better tests_ and _better signals_, not by _pretending not to have a prior_. This could take the form of _finer-grained_ stereotypes. If someone says of me, "Taylor Saotome-Westlake? Oh, he's a _man_, you know what _they're_ like," I would be offended—I mean, I would if I still believed that getting offended ever helps with anything. (It _never helps_.) I'm _not_ like typical men, I _don't like_ typical men, and I don't want to be confused with them. But if someone says, "Taylor Saotome-Westlake? Oh, he's one of those IQ 130, [mid-to-low Conscientiousness and Agreeableness, high Openness](https://en.wikipedia.org/wiki/Big_Five_personality_traits), left-libertarian American Jewish atheist autogynephilic male computer programmers; you know what _they're_ like," my response is to nod and say, "Yeah, pretty much." I'm not _exactly_ like the others, but I don't mind being confused with them.

The other place where I think Murray is hiding the ball (even from himself) is in the section on "reconstructing a moral vocabulary for discussing human differences." (I agree that this is a very important project!) Murray writes—

> I think at the root [of the reluctance to discuss immutable human differences] is the new upper class's conflation of intellectual ability and the professions it enables with human worth. Few admit it, of course. But the evolving zeitgeist of the new upper class has led to a misbegotten hierarchy whereby being a surgeon is _better_ in some sense of human worth than being an insurance salesman, being an executive in a high-tech firm is _better_ than being a housewife, and a neighborhood of people with advanced degrees is _better_ than a neighborhood of high-school graduates. To put it so baldly makes it obvious how senseless it is. There shouldn't be any relationship between these things and human worth.

I take strong issue with Murray's specific examples here—as an [incredibly bitter](http://zackmdavis.net/blog/2012/12/a-philosophy-of-education/) autodidact, I care not at all for formal school degrees, and as my fellow nobody pseudonymous blogger [Harold Lee points out](https://write.as/harold-lee/seizing-the-means-of-home-production), the domestic- and community-focused life of a housewife actually has a lot of desirable properties that many of those stuck in the technology rat race aspire to escape into. But after quibbling with the specific illustrations, I think I'm just going to bite the bullet here?

_Yes_, intellectual ability _is_ a component of human worth! Maybe that's putting it baldly, but I think the _alternative_ is obviously senseless. The fact that I have the ability and motivation to (for example, among many other things I do) write this cool science–philosophy blog about my delusional paraphilia where I do things like summarize and critique the new Charles Murray book, is a big part of _what makes my life valuable_—both to me, and to the people who interact with me. If I were to catch COVID-19 next month and lose 40 IQ points due to oxygen-deprivation-induced brain damage and not be able to write blog posts like this one anymore, that would be _extremely terrible_ for me—it would make my life less-worth-living. (And this kind of judgement is reflected in health and economic policymaking in the form of [quality-adjusted life years](https://en.wikipedia.org/wiki/Quality-adjusted_life_year).) And my friends who love me, love me not as an irreplaceably-unique-but-otherwise-featureless atom of person-ness, but _because_ my specific array of cognitive repetoires makes me a specific person who provides a specific kind of company. There can't be such a thing as _literally_ unconditional love, because to love _someone in particular_, implicitly imposes a condition: you're only committed to love those configurations of matter that constitute an implementation of your beloved, rather than someone or something else.

Murray continues—

> The conflation of intellectual ability with human worth helps to explain the new upper class's insistence that inequalities of intellectual ability must be the product of environmental disadvantage. Many people with high IQs really do feel sorry for people with low IQs. If the environment is to blame, then those unfortunates can be helped, and that makes people who want to help them feel good. If genes are to blame, it makes people who want to help them feel bad. People prefer feeling good to feeling bad, so they engage in confirmation bias when it comes to the evidence about the causes of human differences.

I agree with Murray that this kind of psychology explains a lot of the resistance to hereditarian explanations. But as long as we're accusing people of motivated reasoning, I think Murray's solution is engaging in a similar kind of denial, but just putting it in a different place. The idea that people are unequal in ways that matter is [legitimately too horrifying to contemplate](https://www.lesswrong.com/posts/faHbrHuPziFH7Ef7p/why-are-individual-iq-differences-ok), so liberals [deny the inequality](/2017/Dec/theres-a-land-that-i-see-or-the-spirit-of-intervention/), and conservatives deny [that it matters](https://www.lesswrong.com/posts/NG4XQEL5PTyguDMff/but-it-doesn-t-matter). But I think if you _really_ understand the fact–value distinction and see that the naturalistic fallacy is, in fact, a fallacy (and not even a tempting one), that the progress of humankind has consisted of using our wits to impose our will on an [indifferent universe](https://www.lesswrong.com/posts/sYgv4eYH82JEsTD34/beyond-the-reach-of-god), then the very concept of "too horrifying to contemplate" becomes a grave error. The map is not the territory: _contemplating_ doesn't make things worse; not-contemplating that which is _already there_ can't make things better—and can blind you to opportunities to make things better.

Recently, Richard Dawkins [spurred a lot of criticism on social media for pointing out that](https://www.bioedge.org/bioethics/twitter-piles-on-richard-dawkins-over-eugenics-tweet/13333) selective breeding would work on humans (that is, succeed at increasing the value of the traits selected for in subsequent generations), for the same reasons it works on domesticated nonhuman animals—while stressing, of course, that he deplores the idea: it's just that our moral committments can't constrain the facts. Intellectuals with the reading-comprehension skill, [including Murray](https://archive.is/uaFFF), lept to defend Dawkins and [concur on both points](https://whyevolutionistrue.wordpress.com/2020/02/16/dawkins-makes-a-tweet/)—that eugenics would work, and that it would obviously be terribly immoral. And yet no one seems to bother explaining or arguing _why_ it would be immoral. Yes, obviously _murdering and sterilizing_ people is bad. But if the human race is to continue and people are going to have children _anyway_, those children are going to be born with _some_ distribution of genotypes. There are probably going to be human decisions that do _not_ involve _murdering and sterilizing people_ that would affect that distribution—[perhaps involving](http://intelligence.org/files/EmbryoSelection.pdf) [selection of _in vitro_ fertilized embryos](https://www.gwern.net/Embryo-selection). If the distribution of genotypes were to change in a way that made the next generation grow up happier, and healthier, and smarter, [that would be good](https://www.lesswrong.com/posts/Aud7CL7uhz55KL8jG/transhumanism-as-simplified-humanism) for those children, and it wouldn't hurt anyone else! This is pretty obvious, really? But if no one except nobody pseudonymous bloggers can even say it, how are we to start the work?

The author of the _Xenosystems_ blog mischievously posits [five stages of knowledge of human biodiversity](http://www.xenosystems.net/five-stages-of-hbd/) (in analogy to the famous, albeit [reportedly lacking in empirical support](https://en.wikipedia.org/wiki/K%C3%BCbler-Ross_model), five-stage Kübler-Ross model of grief), culminating in Stage 4: Depression ("Who could possibly have imagined that reality was so evil?") and Stage 5: Acceptance ("Blank slate liberalism really has been a mountain of dishonest garbage, hasn't it? Guess it's time for it to die ...").

I think I got stuck halfway between Stage 4 and 5? It can _simultaneously_ be the case that reality is evil, _and_ that blank slate liberalism _contains_ a mountain of dishonest garbage. That doesn't mean the whole thing is garbage. You _can't_ brainwash a human with random bits; they need to be specific bits with something _good_ in them. I would still be with the program, except that the current coordination equilibrium is [really not working out for me](/2018/Jan/dont-negotiate-with-terrorist-memeplexes/). So it is with respect for the good works enabled by the anti-oppression Schelling point belief, that I set my sights on reorganizing at the other [Schelling point of _just tell the goddamned truth_](https://www.lesswrong.com/posts/tCwresAuSvk867rzH/speaking-truth-to-power-is-a-schelling-point)—not in spite of the consequences, but because of the consequences of what good people can do when we're fully informed. Each of us in her own way.
